Learn R Programming

mem (version 2.5)

max.n.valores: highest n values of a data set, removing Inf and -Inf

Description

highest n values of a data set, removing Inf and -Inf

Usage

# S3 method for n.valores
max(mis.datos, n.max = 1)

Arguments