Learn R Programming

mem (version 2.17)

min.n.valores: lowest n values of a data set, removing Inf and -Inf

Description

lowest n values of a data set, removing Inf and -Inf

Usage

# S3 method for n.valores
min(mis.datos, n.min = 1)

Arguments