Learn R Programming

mem (version 2.5)

roc.analysis: ROC analysis to find optimum parameter value

Description

Function roc.analysis perform a ROC analysis

Usage

roc.analysis(i.data, i.param.values = seq(1.5, 4.5, 0.1), i.graph = F,
  i.graph.file = F, i.graph.file.name = "", i.graph.title = "",
  i.graph.subtitle = "", i.output = ".", ...)

Arguments

i.data

Data frame of input data.

i.param.values

range of i.param values to test.

i.graph

create a graph with the outputs (T/F).

i.graph.file

write the graph to a file.

i.graph.file.name

name of the output file.

i.graph.title

title of the graph.

i.graph.subtitle

subtitle of the graph.

i.output

output directory.

...

other paramaters to be used by memgoodness function.

Value

roc.analysis returns a list. An object of class mem is a list containing at least the following components:

optimum

optimum value.

results

Detailed results of each iteration.

Details

To be written

References

Vega Alonso, Tomas, Jose E Lozano Alonso, Raul Ortiz de Lejarazu, and Marisol Gutierrez Perez. 2004. Modelling Influenza Epidemic: Can We Detect the Beginning and Predict the Intensity and Duration? International Congress Series, Options for the Control of Influenza V. Proceedings of the International Conference on Options for the Control of Influenza V, 1263 (June): 281-83. doi:10.1016/j.ics.2004.02.121. Vega, Tomas, Jose Eugenio Lozano, Tamara Meerhoff, Rene Snacken, Joshua Mott, Raul Ortiz de Lejarazu, and Baltazar Nunes. 2013. Influenza Surveillance in Europe: Establishing Epidemic Thresholds by the Moving Epidemic Method. Influenza and Other Respiratory Viruses 7 (4): 546-58. doi:10.1111/j.1750-2659.2012.00422.x. Vega, Tomas, Jose E. Lozano, Tamara Meerhoff, Rene Snacken, Julien Beaute, Pernille Jorgensen, Raul Ortiz de Lejarazu, et al. 2015. Influenza Surveillance in Europe: Comparing Intensity Levels Calculated Using the Moving Epidemic Method. Influenza and Other Respiratory Viruses 9 (5): 234-46. doi:10.1111/irv.12330.

Examples

Run this code
# Castilla y Leon Influenza Rates data
data(flucyl)
# ROC analysis
epi.roc<-roc.analysis(flucyl,i.param.values=seq(2.6,2.8,0.1),i.detection.values=seq(2.6,2.8,0.1))
epi.roc$results

Run the code above in your browser using DataLab